Connected Thermostat draft field savings metrics module
=======================================================

[![Build Status](https://github.com/EPAENERGYSTAR/epathermostat/actions/workflows/python-app.yaml/badge.svg)](https://github.com/EPAENERGYSTAR/epathermostat/actions/workflows/python-app.yaml)

Calculate temperature/run-time savings for connected thermostats using this
package.

Documentation
-------------

Documentation is on [Read the Docs](http://epathermostat.readthedocs.io/en/latest/).

Tests
-----

Tests for this package can be run using the py.test tool as follows:

    $ py.test

For additional information and options for running tests, please see
the [pytest documentation](https://pytest.org/latest/getting-started.html).
